@@ -19,7 +19,8 @@ def run(rule_set: RuleSet,
         exposure_dict: dict = dict(),
         roster_gen: Roster = None,
         verbose=False) -> Roster:
-    if player_settings.exist():
+    players = player_pool
+    if player_settings.exist() or constraints.exist():
         players = pool.filter_pool(
             deepcopy(player_pool),
             player_settings,
